@@ -1,16 +1,22 @@
-package fr.ird.osmose.util.version;
-
-import java.util.Calendar;
-
 /*
  * To change this license header, choose License Headers in Project Properties.
  * To change this template file, choose Tools | Templates
  * and open the template in the editor.
  */
+package fr.ird.osmose.util.version;
+
+import au.com.bytecode.opencsv.CSVReader;
+import au.com.bytecode.opencsv.CSVWriter;
+import fr.ird.osmose.util.Separator;
+import java.io.FileReader;
+import java.io.FileWriter;
+import java.io.IOException;
+import java.util.Calendar;
+import java.util.List;
 
 /**
  *
- * @author nbarrier
+ * @author pverley
  */
 public class Version3Update3Release3 extends AbstractVersion {
 
@@ -20,11 +26,9 @@ public class Version3Update3Release3 extends AbstractVersion {
 
     @Override
     void updateParameters() {
-                
+        // Nothing to be done for this version
         this.updateKey("grid.ncolumn", "grid.nlon");
         this.updateKey("grid.nline", "grid.nlat");
-        
-        // Nothing to be done for this version
+
     }
-    
-}
+}
\ No newline at end of file
